<?php
/**
 * SMOF Interface
 *
 * @package     WordPress
 * @subpackage  SMOF
 * @since       1.4.0
 * @author      Syamil MJ
 */


/**
 * Admin Init
 *
 * @uses wp_verify_nonce()
 * @uses header()
 *
 * @since 1.0.0
 */
function optionsframework_admin_init()
{
	// Rev up the Options Machine
	global $of_options, $options_machine, $smof_data, $smof_details;
	if (!isset($options_machine))
		$options_machine = new Options_Machine($of_options);

	do_action('optionsframework_admin_init_before', array(
			'of_options'		=> $of_options,
			'options_machine'	=> $options_machine,
			'smof_data'			=> $smof_data
		));

	if (empty($smof_data['smof_init'])) { // Let's set the values if the theme's already been active
		of_save_options($options_machine->Defaults);
		of_save_options(date('r'), 'smof_init');
		$smof_data = of_get_options();
		$options_machine = new Options_Machine($of_options);
	}

	do_action('optionsframework_admin_init_after', array(
			'of_options'		=> $of_options,
			'options_machine'	=> $options_machine,
			'smof_data'			=> $smof_data
		));

}

/**
 * Create Options page
 *
 * @uses add_theme_page()
 * @uses add_action()
 *
 * @since 1.0.0
 */
function optionsframework_add_admin() {
  $add_ob = 'add_';
	$of_page = add_menu_page( 'Purity', 'Purity', 'manage_options', 'optionsframework', 'optionsframework_options_page', '', 58 );
	// Add framework functionaily to the head individually
	add_action("admin_enqueue_scripts", 'of_load_only');
	add_action("admin_enqueue_scripts",'of_style_only');
}


/**
 * Build Options page
 *
 * @since 1.0.0
 */
function optionsframework_options_page(){

	global $options_machine;

	/*
	//for debugging

	$smof_data = of_get_options();
	print_r($smof_data);

	*/

	include_once( ADMIN_PATH . 'front-end/options.php' );

}

/**
 * Create Options page
 *
 * @uses wp_enqueue_style()
 *
 * @since 1.0.0
 */
function of_style_only(){
	wp_enqueue_style('admin-style', ADMIN_DIR . 'assets/css/admin-style.css');
	wp_enqueue_style('chosen', ADMIN_DIR . 'assets/css/chosen.css');
	//wp_enqueue_style('color-picker', ADMIN_DIR . 'assets/css/colorpicker.css');
	wp_enqueue_style('jquery-ui-custom-admin', ADMIN_DIR .'assets/css/jquery-ui-custom.css');

	if ( !wp_style_is( 'wp-color-picker','registered' ) ) {
		wp_register_style( 'wp-color-picker', ADMIN_DIR . 'assets/css/color-picker.min.css' );
	}
	wp_enqueue_style( 'wp-color-picker' );
	do_action('of_style_only_after');
}

/**
 * Create Options page
 *
 * @uses add_action()
 * @uses wp_enqueue_script()
 *
 * @since 1.0.0
 */
function of_load_only()
{
	//add_action('admin_head', 'smof_admin_head');

	wp_enqueue_script('jquery-ui-core', '', '', '', true);
	wp_enqueue_script('jquery-ui-sortable', '', '', '', true);
	wp_enqueue_script('jquery-ui-slider', '', '', '', true);
	wp_enqueue_script('jquery-input-mask', ADMIN_DIR .'assets/js/jquery.maskedinput-1.2.2.js', array( 'jquery' ), '', true);
	wp_enqueue_script('tipsy', ADMIN_DIR .'assets/js/jquery.tipsy.js', array( 'jquery' ), '' ,true);
	wp_enqueue_script('cookie', ADMIN_DIR . 'assets/js/cookie.js', 'jquery', '', true);
	wp_enqueue_script('toggles', ADMIN_DIR .'assets/js/toggles.min.js', array( 'jquery' ), '', true);
	wp_enqueue_script('smof', ADMIN_DIR .'assets/js/smof.js', array( 'jquery' ), '', true);
	wp_enqueue_script('chosen', ADMIN_DIR .'assets/js/chosen.jquery.min.js', array( 'jquery' ), '', true);

	wp_localize_script( 'smof', 'VNTD_SMOF',
		array(
			'tr' => array(
				'new' => esc_html__( 'New', 'purity' ),
				'title' => esc_html__( 'Title', 'purity' ),
				'image_url' => esc_html__( 'Image URL', 'purity' ),
				'link_url' => esc_html__( 'Link URL', 'purity' ),
				'slide_caption' => esc_html__( 'Slide Caption', 'purity' ),
				'optional' => esc_html__( 'optional', 'purity' ),
				'upload' => esc_html__( 'Upload', 'purity' ),
				'delete' => esc_html__( 'Delete', 'purity' ),
				'edit' => esc_html__( 'Edit', 'purity' )
			)
		)
	);

	/**
	 * Enqueue scripts for file uploader
	 */

	if ( function_exists( 'wp_enqueue_media' ) )
		wp_enqueue_media();

	do_action('of_load_only_after');

}


/**
 * Ajax Save Options
 *
 * @uses get_option()
 *
 * @since 1.0.0
 */
function of_ajax_callback()
{
	global $options_machine, $of_options;

	$nonce = $_POST['security'];

	if (! wp_verify_nonce($nonce, 'of_ajax_nonce') ) die('-1');

	//get options array from db
	$all = of_get_options();

	$save_type = $_POST['type'];

	//Uploads
	if($save_type == 'upload')
	{

		$clickedID = $_POST['data']; // Acts as the name
		$filename = $_FILES[$clickedID];
       	$filename['name'] = preg_replace('/[^a-zA-Z0-9._\-]/', '', $filename['name']);

		$override['test_form'] = false;
		$override['action'] = 'wp_handle_upload';
		$uploaded_file = wp_handle_upload($filename,$override);

			$upload_tracking[] = $clickedID;

			//update $options array w/ image URL
			$upload_image = $all; //preserve current data

			$upload_image[$clickedID] = $uploaded_file['url'];

			of_save_options($upload_image);


		 if(!empty($uploaded_file['error'])) {echo 'Upload Error: ' . $uploaded_file['error']; }
		 else { echo '' . $uploaded_file['url']; } // Is the Response

	}
	elseif($save_type == 'image_reset')
	{

			$id = $_POST['data']; // Acts as the name

			$delete_image = $all; //preserve rest of data
			$delete_image[$id] = ''; //update array key with empty value
			of_save_options($delete_image ) ;

	}
	elseif($save_type == 'backup_options')
	{

		$backup = $all;
		$backup['backup_log'] = date('r');

		of_save_options($backup, BACKUPS) ;

		die('1');
	}
	elseif($save_type == 'restore_options')
	{

		$smof_data = of_get_options(BACKUPS);

		of_save_options($smof_data);

		die('1');
	} else if ( $save_type == 'import_options' ) {

		if ( function_exists( 'purity_options_decode_data' ) && isset( $_POST['data'] ) ) {
			$smof_data = purity_options_decode_data( $_POST['data'] );
			of_save_options( $smof_data );
		}

		die('1');

	}
	elseif ($save_type == 'save')
	{

		wp_parse_str(stripslashes($_POST['data']), $smof_data);
		unset($smof_data['security']);
		unset($smof_data['of_save']);
		of_save_options($smof_data);


		die('1');
	}
	elseif ($save_type == 'reset')
	{
		of_save_options($options_machine->Defaults);

        die('1'); //options reset
	}
	elseif ( $save_type == 'import_old_options' )
	{
		global $smof_data;
		unset($smof_data['security']);
		unset($smof_data['of_save']);
		$new_data = of_purity_get_migrated_options( $smof_data );
		of_save_options( $new_data );

        die('1'); //options reset
	}

  	die();
}

function of_purity_get_migrated_options( $smof_data ) {

	// Gather old options
	$old_options = get_option( 'option_tree' );

	if ( is_array( $old_options ) ) {
		foreach ( $smof_data as $key => $value ) {
			$old_key = str_replace( 'purity_', '', $key );

			// Slides
			if ( $old_key == 'slider_slides' ) {
				$old_key = 'slider_slider';
			}

			// Check if the option is set in the old theme options
			if ( ! isset( $old_options[ $old_key ] ) ) continue;

			$old_value = $old_options[ $old_key ];

			// Slider
			if ( $old_key == 'slider_slider' ) {
				$slides = array();
				foreach ( $old_value as $i => $value ) {
					$value[ 'url' ] = $value['image'];
					unset( $value['image'] );
					$slides[ $value['order'] ] = $value;
				}
				$smof_data[ $key ] = $slides;
			} else if ( is_array( $old_value ) ) {
				if ( $old_key == 'bg_style' ) {
					$old_value = 'yes';
					$smof_data[ $key ] = $old_value;
				}
			} else {
				// Non standard values
				if ( $old_value == 'Four Columns' ) {
					$old_value = '4cols';
				} else if ( $old_value == 'Three Columns' ) {
					$old_value = '3cols';
				} else if ( $old_value == 'Five Columns' ) {
					$old_value = '5cols';
				} else if ( $old_value == 'Footer 2' ) {
					$old_value = 'footer2';
				} else if ( $old_value == 'Wide' ) {
					$old_value = 'wide';
				} else if ( $old_value == 'Slide' ) {
					$old_value = 'slide';
				} else if ( $old_value == 'False' ) {
					$old_value = 'false';
				} else if ( $old_value == 'Right Sidebar' ) {
					$old_value = 'sidebar_right';
				} else if ( $old_value == 'Left Sidebar' ) {
					$old_value = 'sidebar_left';
				} else if ( $old_value == 'Fullwidth' ) {
					$old_value = 'fullwidth';
				} else if ( $old_value == 'Big Thumbnail' ) {
					$old_value = 'big_thumbnail';
				} else if ( $old_value == 'Medium Thumbnail' ) {
					$old_value = 'medium_thumbnail';
				} else if ( $old_value == 'Small Thumbnail' ) {
					$old_value = 'small_thumbnail';
				} else if ( $old_value == 'Dark' ) {
					$old_value = 'dark';
				} else if ( $old_value == 'Helvetica Neue' || $old_value == 'Arial' || $old_value == 'Helvetica' ) {
					$old_value = 'Arial';
				}

				$smof_data[ $key ] = $old_value;
			}

		}
		// Sidebars
		$old_sidebars = get_option( 'sidebarmanager_options' );
		if ( isset( $old_sidebars['custom_sidebar'] ) && is_array( $old_sidebars['custom_sidebar'] ) ) {
			$old_sidebars = $old_sidebars['custom_sidebar'];
			$sidebars = array();
			$i = 1;
			foreach ( $old_sidebars as $i => $sidebar_title ) {
				$sidebars[ $i ] = array(
					'order' => $i,
					'title' => $sidebar_title
				);
				$i++;
			}
			$smof_data[ 'purity_sidebar_generator' ] = $sidebars;
		}
	}

	// Test
	return $smof_data;

}
