<?php

//
// Purity Theme Functions
//
// Author: Veented
// URL: http://themeforest.net/user/Veented/
//

// Localization;

function vntd_localization() {
	load_theme_textdomain( 'purity', get_template_directory() . '/lang' );
}
add_action( 'after_setup_theme', 'vntd_localization' );

// Plugins Manager - TGMPA
require_once( get_template_directory() . '/plugins/plugins-config.php' );

// Admin Panel

if ( ! function_exists( 'optionsframework_admin_init') ) { // Theme Options Panel
	require_once( get_template_directory() . '/admin/theme-options/index.php' );
}

//
// Custom menu
//

add_action( 'init', 'vntd_register_custom_menu' );

function vntd_register_custom_menu() {
	register_nav_menu('custom_menu', esc_html__('Main Navigation','purity'));
	register_nav_menu('vntd_topbar_menu', esc_html__('Top Bar Navigation','purity'));
}

// Helper

if ( ! function_exists( 'purity_generate_slug' ) ) {
	function purity_generate_slug( $phrase, $maxLength = null ) {
		if ( $maxLength == null ) $maxLength = 45;
    $result = strtolower($phrase);
    $result = preg_replace("/[^a-z0-9\s-]/", "", $result);
    $result = trim(preg_replace("/[\s-]+/", " ", $result));
    $result = trim(substr($result, 0, $maxLength));
    $result = preg_replace("/\s/", "-", $result);
    return $result;
	}
}

//
// Register Sidebars
//

if ( ! function_exists( 'purity_register_sidebars' ) ) {

	function purity_register_sidebars() {

		if ( ! function_exists( 'register_sidebar' ) ) return;

		register_sidebar( array(
        'name' => esc_html__( 'Blog Sidebar', 'purity' ),
        'id' => 'sidebar_blog',
        'before_widget' => '<div id="%1$s" class="sidebar_item %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h5>',
        'after_title' => '</h5>',
    ) );
		register_sidebar(array(
        'name' => esc_html__( 'Page Sidebar', 'purity' ),
        'id' => 'sidebar_page',
        'before_widget' => '<div id="%1$s" class="sidebar_item %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h5>',
        'after_title' => '</h5>',
    ));
		register_sidebar(array(
        'name' => esc_html__( 'Contact Sidebar', 'purity' ),
        'id' => 'sidebar_contact',
        'before_widget' => '<div id="%1$s" class="sidebar_item %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h5>',
        'after_title' => '</h5>',
    ));
		register_sidebar(array(
        'name' => esc_html__( 'Archives/Search Sidebar', 'purity' ),
        'id'	=> 'archives',
        'before_widget' => '<div id="%1$s" class="sidebar_item %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h5>',
        'after_title' => '</h5>',
    ));
    register_sidebar(array(
        'name' => esc_html__( 'Footer Widgets Area', 'purity' ),
        'id'	=> 'footer_widgets',
        'before_widget' => '<li id="%1$s" class="sidebar_item %2$s">',
        'after_widget' => '</li>',
        'before_title' => '<h5>',
        'after_title' => '</h5>',
    ));

	    if ( class_exists('Woocommerce') ) { // If WooCommerce is enabled, activate related sidebars

	    	register_sidebar(array(
	    	    'name' => esc_html__( 'WooCommerce Shop Page', 'purity' ),
	    	    'id'	=> 'woocommerce_shop',
	    	    'before_widget' => '<div id="%1$s" class="sidebar-widget %2$s">',
	    	    'after_widget' => '</div>',
	    	    'before_title' => '<h5>',
	    	    'after_title' => '</h5>',
	    	));

	    	register_sidebar(array(
	    	    'name' => esc_html__( 'WooCommerce Product Page', 'purity' ),
	    	    'id'	=> 'woocommerce_product',
	    	    'before_widget' => '<div id="%1$s" class="sidebar-widget %2$s">',
	    	    'after_widget' => '</div>',
	    	    'before_title' => '<h5>',
	    	    'after_title' => '</h5>',
	    	));

	    }

			// Sidebar generator in Theme Options

			global $smof_data;

			if ( ! $smof_data ) $smof_data = array();

			if ( array_key_exists( 'purity_sidebar_generator', $smof_data ) ) {

				//var_dump( $smof_data[ 'purity_sidebar_generator' ] );
				if ( $smof_data[ 'purity_sidebar_generator' ] > 0 ) {
					foreach ( $smof_data['purity_sidebar_generator'] as $sidebar ) {
						register_sidebar( array(
							'name' => esc_textarea( $sidebar['title'] ),
							'id' => purity_generate_slug( $sidebar['title'], 45 ),
							'before_widget' => '<div class="sidebar_item sidebar-widget">',
							'after_widget' => '</div>',
							'before_title' => '<h5>',
							'after_title' => '</h5>',
						) );
					}
				}
			}

	}

	add_action( 'widgets_init', 'purity_register_sidebars' );

}

//
// Large image size
//

if ( function_exists( 'add_theme_support' ) ) {
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'automatic-feed-links' );
	add_image_size( 'large', 690, '', true );
	if ( ! isset( $content_width ) ) $content_width = 960;
	set_post_thumbnail_size( 280, 210, true ); // Normal post thumbnails
	add_image_size( 'screen-shot', 720, 540 ); // Full size screen
	add_theme_support( "title-tag" );
	add_theme_support('woocommerce');
}

//
// Scripts and Styles
//

if ( ! function_exists( 'vntd_enqueue_scripts' ) ) {
	function vntd_enqueue_scripts() {
		if ( ! is_admin() ) {

			wp_register_script('purity-custom', get_template_directory_uri() . '/js/custom.js', array('jquery'), '1.0.2' );
			wp_register_script('contact-form', get_template_directory_uri() . '/js/contact-form.js', array('jquery'));
			wp_register_script('flexslider', get_template_directory_uri() . '/js/jquery.flexslider-min.js', array('jquery'));
			wp_register_script('prettyphoto', get_template_directory_uri() . '/js/jquery.prettyPhoto.js', array('jquery'), NULL, false);
			wp_register_script('quicksand', get_template_directory_uri() . '/js/jquery.quicksand.min.js', array('jquery'));
			wp_register_script('isotope', get_template_directory_uri() . '/js/jquery.isotope.min.js', array('jquery'));
			wp_register_script('easing', get_template_directory_uri() . '/js/jquery.easing.js', array('jquery'));

			wp_enqueue_script('jquery-ui');
			wp_enqueue_script('contact-form');
			wp_enqueue_script('purity-custom');
			wp_enqueue_script('easing');
			wp_enqueue_script('prettyphoto');
			wp_enqueue_script('flexslider');

			wp_register_style('purity-custom', get_template_directory_uri() . '/css/custom.css', array( 'purity-styles' ) );
			wp_register_style('purity-responsive', get_template_directory_uri() . '/css/responsive.css');
			wp_register_style('purity-retina', get_template_directory_uri() . '/css/retina.css');
			wp_register_style('prettyphoto', get_template_directory_uri() . '/css/scripts/prettyPhoto.css');
			wp_register_style('purity-flexslider', get_template_directory_uri() . '/css/scripts/flexslider.css');
			wp_register_style('font-awesome', get_template_directory_uri() . '/css/font-awesome/css/font-awesome.min.css');

			wp_enqueue_style('purity-styles', get_template_directory_uri() . '/style.css' ); // Main Stylesheet
			wp_enqueue_style('purity-custom');
			wp_enqueue_style('prettyphoto');
			wp_enqueue_style('purity-flexslider');
			wp_enqueue_style('font-awesome');

			wp_dequeue_style( 'woocommerce_prettyPhoto_css' ); // Deregister WooCommerce styles
			wp_dequeue_style( 'woocommerce_frontend_styles' );

			// Custom CSS
			if ( purity_get_option( 'custom_css' ) != '' ) {
				$custom_css = purity_get_option( 'custom_css' );
				wp_add_inline_style( 'purity-styles', $custom_css );
			}

			// Google Maps
			$api_key = '';

			global $smof_data;
			if ( array_key_exists( 'purity_google_maps_api_key', $smof_data ) ) {
				if ( $smof_data[ 'purity_google_maps_api_key' ] != '' ) {
					$api_key = esc_attr( $smof_data[ 'purity_google_maps_api_key' ] );
				}
			}

			wp_register_script( 'google-map-sensor', '//maps.google.com/maps/api/js?key=' . esc_attr( $api_key ) , array( 'jquery' ) );

			if ( function_exists('purity_get_option') ) {
				if ( purity_get_option('theme_responsive') != 'no' ) wp_enqueue_style('purity-responsive');
				if ( purity_get_option('theme_retina') != 'no' ) wp_enqueue_style('purity-retina');

				if ( purity_get_option( 'theme_skin' ) == "dark" ) {
					wp_register_style( 'theme_skin', get_template_directory_uri() . '/css/skins/Dark.css', array( 'purity-styles' ) );
					wp_enqueue_style( 'theme_skin' );
				}
			}

			// Dynamic CSS
	    if ( ! has_filter( 'purity-remove-dynamic-css' ) ) {
	    	wp_enqueue_style( 'purity-dynamic-css', admin_url( 'admin-ajax.php' ) . '?action=purity_dynamic_css', array( 'purity-styles' ) );
	    }

		}
	}
	add_action('wp_enqueue_scripts', 'vntd_enqueue_scripts');
}

// Dynamic Stylesheet

function purity_dynamic_css_fn() {
	require( get_template_directory() . '/css/style-dynamic.php' );
	exit;
}

add_action( 'wp_ajax_purity_dynamic_css', 'purity_dynamic_css_fn' );
add_action( 'wp_ajax_nopriv_purity_dynamic_css', 'purity_dynamic_css_fn' );

// Google Fonts

if ( ! function_exists( 'vntd_google_font' ) ) {
	function vntd_google_font() {

		// Google Font

		if ( function_exists('purity_get_option') ) {

			if ( purity_get_option('font_heading') && purity_get_option('font_heading') != "League Gothic" && purity_get_option('font_heading') != "Arial" && purity_get_option('font_heading') != "none" ) {
				wp_register_style('google-font-heading', '//fonts.googleapis.com/css?family='.str_replace('+','', esc_attr( purity_get_option('font_heading') ) ).'&subset=latin,latin-ext');
				wp_enqueue_style('google-font-heading');
			}

			if ( purity_get_option('font_body') && purity_get_option('font_body') != "Arial" && purity_get_option('font_body') != "League Gothic" && purity_get_option('font_body') != "Helvetica" && purity_get_option('font_body') != "Helvetica Neue" && purity_get_option('font_body') != "none" ){
				wp_register_style('google-font-body', '//fonts.googleapis.com/css?family=' . str_replace('+','', esc_attr( purity_get_option('font_body') ) ));
				wp_enqueue_style('google-font-body');
			}

		}

	}

	add_action('wp_enqueue_scripts', 'vntd_google_font');
}

// Comments Script

if ( ! function_exists( 'vntd_comments' ) ) {
	function vntd_comments() {
		if(is_singular() || is_page())
		wp_enqueue_script( 'comment-reply' );
	}
	add_action('wp_print_scripts', 'vntd_comments');
}

// Portfolio Scripts

if ( ! function_exists( 'vntd_portfolio' ) ) {
	function vntd_portfolio() {
		if (is_page_template('template-portfolio.php') ||
		is_page_template('template-portfolio-one-1.php') ||
		is_page_template('template-portfolio-one-2.php') ||
		is_page_template('template-portfolio-one-3.php') ||
		is_page_template('template-portfolio-two-1.php') ||
		is_page_template('template-portfolio-two-2.php') ||
		is_page_template('template-portfolio-two-3.php') ||
		is_page_template('template-portfolio-three-2.php') ||
		is_page_template('template-portfolio-three-3.php') ||
		is_page_template('template-portfolio-four-1.php') ||
		is_page_template('template-portfolio-four-2.php') ||
		is_page_template('template-portfolio-four-3.php')
		){
		wp_enqueue_script('isotope');
		}

		if(is_page_template('template-contact.php')) {
		wp_enqueue_script('google-map');
		}
	}
	add_action('wp_print_scripts', 'vntd_portfolio');
}

// WooCommerce Support

if ( class_exists( 'Woocommerce' ) ) {
	require_once( get_template_directory() . '/plugins/woocommerce/config.php' );
}

// Homepage Styles

if ( ! function_exists( 'vntd_css_home' ) ) {
	function vntd_css_home() {
		if ( is_page_template('template-home.php') )
		wp_enqueue_style('nivoslider');
	}
	add_action( 'wp_print_styles', 'vntd_css_home' );
}

//
// Comments Layout
//

if ( ! function_exists( 'vntd_ts_comment' ) ) {
	function vntd_ts_comment($comment, $args, $depth) {
	   $GLOBALS['comment'] = $comment; ?>

		<li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
		<div id="comment-<?php comment_ID(); ?>">

			<div class="avatar-holder">
	            <?php echo get_avatar($comment,$size='48'); ?>
	        </div>

	        <div class="comment-entry">
	            <span>
	            	<?php printf('<strong>%s</strong>', get_comment_author_link()); echo ' '; esc_html_e('on','purity');echo ' '; echo get_comment_date('M d, Y'); ?>
					<?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth'], 'reply_text' => esc_html( purity_get_option('tr_reply') ) ))) ?><?php edit_comment_link( esc_html__(' | Edit','purity'),'  ','') ?>
	            </span>
	            <?php if ($comment->comment_approved == '0') : ?>
	         <em><?php esc_html_e('Your comment is awaiting moderation.', 'purity') ?></em>
	         <br />
			<?php endif; ?>

	        <?php comment_text() ?>

	        </div>


	<?php
	}
}

//
// General Functions
//

require_once( get_template_directory() . '/functions/general-functions.php');

if ( ! function_exists( 'vntd_crop_img' ) ) {
	function vntd_crop_img($url, $width, $height = NULL){
		require_once('includes/aq_resizer.php');
		return aq_resize($url,$width,$height,true,true,true);
	}
}

//
// Blog Functions
//

require_once( get_template_directory() . '/functions/blog-functions.php');

//
// Homepage Functions
//

require_once( get_template_directory() . '/functions/homepage-functions.php');


//
// Portfolio Functions
//

if ( ! function_exists( 'vntd_wrapper_class' ) ) {
	function vntd_wrapper_class() {
		if ( purity_get_option('site_layout') == "Wide" || purity_get_option('site_layout') == "wide" ) {
			echo 'class="vntd-wide"';
		}
	}
}

//
// Dashboard Functions
//

if ( ! function_exists( 'vntd_admin_scripts' ) ) {
	function vntd_admin_scripts() {
		wp_enqueue_media();
		wp_enqueue_script('media-upload');

		wp_register_script('my-upload', get_template_directory_uri() . '/admin/theme-options/assets/js/jquery.upload.js', array('jquery'));
		wp_enqueue_script('my-upload');
		wp_register_script('media-uploader', get_template_directory_uri() . '/admin/theme-options/assets/js/media-uploader.js', array('jquery'), true);

		wp_enqueue_script('media-uploader');
		wp_enqueue_script('thickbox');

		wp_register_script( 'purity-admin-js', get_template_directory_uri() . '/admin/theme-options/assets/js/jquery.dashboard.js', array( 'jquery' ), '1.0' );
		wp_enqueue_script( 'purity-admin-js', '', '', '', true );

		$updates_url = admin_url( 'themes.php?page=install-required-plugins' );

		wp_localize_script( 'purity-admin-js', 'VNTDWP',
			array(
	      'themeurl' => get_template_directory_uri(),
	      'updateInfo' => esc_html__( 'Theme: To get instant access to an update, please visit ', 'purity' ) . ' <a href="https://plugins.veented.com/" target="_blank">Veented Plugins</a> ' . esc_html__( ' service.', 'purity' ),
	      'updateInfoAvailable' => sprintf( esc_html__( 'Theme: There seem to be plugin updates available in', 'purity' ) . ' <a href="%s">' . esc_html__( 'Appearance / Install Plugins', 'purity' ) . '</a> ' . esc_html__( 'menu. If this particular plugin update is not available there, please visit ' , 'purity' ) . ' <a href="https://plugins.veented.com/" target="_blank">Veented Plugins</a> ' . esc_html__( 'service.', 'purity' ), $updates_url ),
	      'updateInfoExternal' => sprintf( esc_html__( 'Theme: You may always find the newest plugin version inside the latest theme package (downloaded from ThemeForest). If the latest plugin version is not there, it means that the update was released very recently. In that case, you may use our', 'purity' ) . ' <a href="https://plugins.veented.com/" target="_blank">Veented Plugins</a> ' . esc_html__( 'service.', 'purity' ), $updates_url ),
	    )
		);

		// Font Awesome Admin
		wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome/css/font-awesome.min.css' );

	}
	add_action('admin_print_scripts', 'vntd_admin_scripts');
}

if ( ! function_exists( 'vntd_admin_styles' ) ) {
	function vntd_admin_styles() {
		wp_enqueue_style('thickbox');
		wp_enqueue_style('media');
	}
	if ( is_admin() ) {
		add_action('admin_print_styles', 'vntd_admin_styles');
	}
}

//
// Get theme option (new)
//

if ( ! function_exists( 'purity_get_option' ) ) {
	function purity_get_option( $opt_name ) {

		global $smof_data;

		$prefix = 'purity_';

		if ( isset( $smof_data[ $prefix . $opt_name ] ) ) {
			return $smof_data[ $prefix . $opt_name ];
		}

		return null;

	}
}

//
// Is an upgrade (if old theme options exist in database)
//

if ( ! function_exists( 'purity_is_upgrade' ) ) {
	function purity_is_upgrade() {

		global $table_prefix, $wpdb;
    $table_name = $table_prefix . 'bp_option_tree';

		$option_tables = $wpdb->get_results( $wpdb->prepare( "show tables like '%s'", $table_name ), ARRAY_A );

		if ( is_array( $option_tables ) && sizeof( $option_tables ) > 0 ) return true;

		return false;

	}
}
