<?php

if ( ! function_exists( 'purity_manage_woocommerce_styles' ) ) {
	add_action( 'wp_enqueue_scripts', 'purity_manage_woocommerce_styles', 99 );

	function purity_manage_woocommerce_styles() {
		remove_action( 'wp_head', array( $GLOBALS['woocommerce'], 'generator' ) );
	}
}

if ( ! function_exists( 'vntd_shopping_cart_icon' ) ) {
	function vntd_shopping_cart_icon() {
		$cart_url = '';
		if ( function_exists( 'wc_get_cart_url' ) ) {
			$cart_url = wc_get_cart_url();
		}
		echo '<div class="vntd-shopping-cart"><div class="vntd-cart"><a href="' . esc_url( $cart_url ) . '" class="vntd-cart-icon"></a>';
		echo '<div class="nav-cart-products"><div class="widget_shopping_cart"><div class="widget_shopping_cart_content"></div></div></div>';
		echo '</div></div>';
	}
}

if ( ! function_exists( 'purity_woocommerce_init_settings' ) ) {
	function purity_woocommerce_init_settings() {
		$catalog = array(
			'width' 	=> '300',	// px
			'height'	=> '360',	// px
			'crop'		=> 1 		// true
		);

		$single = array(
			'width' 	=> '600',	// px
			'height'	=> '',	// px
			'crop'		=> 1 		// true
		);

		$thumbnail = array(
			'width' 	=> '120',	// px
			'height'	=> '120',	// px
			'crop'		=> 0 		// false
		);

		// Image sizes
		update_option( 'shop_catalog_image_size', $catalog ); 		// Product category thumbs
		update_option( 'shop_single_image_size', $single ); 		// Single product image
		update_option( 'shop_thumbnail_image_size', $thumbnail ); 	// Image gallery thumbs

		wp_register_script('woo-js', get_template_directory_uri() . '/plugins/woocommerce/assets/woocommerce-scripts.js', array('jquery'));
		wp_enqueue_script('woo-js');

		wp_register_style('woocommerce-custom', get_template_directory_uri() . '/plugins/woocommerce/assets/woocommerce-styling.css');
		wp_enqueue_style('woocommerce-custom');

	}
	add_action('init', 'purity_woocommerce_init_settings', 1);
}

if ( ! function_exists( 'purity_loop_columns' ) ) {
	add_filter('loop_shop_columns', 'purity_loop_columns');
	function purity_loop_columns() {
		return 999; // 3 products per row
	}
}

//remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
//remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0);
remove_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30);
remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20);
// remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10);
// remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10);

if ( ! function_exists( 'purity_theme_wrapper_start' ) ) {
	add_action('woocommerce_before_shop_loop', 'purity_theme_wrapper_start', 10);
	function purity_theme_wrapper_start() {

		$order = $orderby = '';

		if(isset($_GET['product_orderby'])) $orderby = $_GET['product_orderby'];
		if(isset($_GET['product_order'])) $order = $_GET['product_order'];

		if(!$orderby) $orderby = esc_html__('Default Order','purity');
		//

		$output = '<ul class="product-filters"><li class="product-orderby"><span>'.esc_html__('Sort by','purity').' <strong>'.ucfirst($orderby).'</strong></span><ul>';

		// OrderBy

		$orderby_list = array('default' => esc_html__('Default Order','purity'),'title' => esc_html__('Name','purity'),'price' => esc_html__('Price','purity'),'date' => esc_html__('Date','purity'),'popularity' => esc_html__('Popularity','purity'));

		foreach($orderby_list as $single_order) {

			$params_orderby = array_merge($_GET, array("product_orderby" => array_search($single_order,$orderby_list)));
			$params_orderby_url = http_build_query($params_orderby);

			$output .= '<li><a href="?'.$params_orderby_url.'">'.esc_html__('Sort by','purity').' '.$single_order.'</a></li>';
		}

		$output .= '</ul></li>';

		// Order

		if(!$order || $order == 'asc') {
			$order_opposite = 'desc';
			$arrow_direction = 'down';
		} else {
			$order_opposite = 'asc';
			$arrow_direction = 'up';
		}

		$params_order = array_merge($_GET, array("product_order" => $order_opposite));
		$params_order_url = http_build_query($params_order);

		$output .= '<li class="product-order"><a href="?'.$params_order_url.'"><i class="fa fa-chevron-'.$arrow_direction.'"></i></a></li>';

		// Product Count

		$current_count = '';

		if(isset($_GET['product_count'])) $current_count = $_GET['product_count'];


		$products_count = get_option('posts_per_page');

		if(!$current_count) $current_count = $products_count;

		$output .= '<li class="product-count"><span>'.esc_html__('Show','purity').' <strong>'.$current_count.'</strong> '.esc_html__('products','purity').'</span><ul>';


		$count_array = array($products_count,$products_count*2,$products_count*3);

		foreach ($count_array as $count) {
			$params_count = array_merge($_GET, array("product_count" => $count));
			$output .= '<li><a href="?'.http_build_query($params_count).'">'.esc_html__('Show','purity').' '.$count.' '.esc_html__('Show','purity').'</a></li>';
		}

		$output .= '</ul></li></ul>';


		echo '' . $output;
	}
}

//
// Ordering
//

if ( ! function_exists( 'purity_woocommerce_custom_ordering' ) ) {
	add_action('woocommerce_get_catalog_ordering_args', 'purity_woocommerce_custom_ordering', 20);

	function purity_woocommerce_custom_ordering($args) {

		$order = $orderby = '';

		if(isset($_GET['product_order'])) $order = $_GET['product_order'];
		if(isset($_GET['product_orderby'])) $orderby = $_GET['product_orderby'];

		//$_GET['product_count']

		if($order) $args['order'] = $order;
		if($orderby && $orderby != 'price' && $orderby != 'popularity') $args['orderby'] = $orderby;
		//$args['meta_key'] = '';

		if($orderby == 'price') {
			$args['orderby'] = 'meta_value_num';
			$args['meta_key'] = '_price';
		}elseif($orderby == 'popularity'){
			$args['orderby'] = 'meta_value_num';
			$args['meta_key'] = 'total_sales';
		}

		return $args;

	}
}

//
// Product Count
//

if ( ! function_exists( 'vntd_loop_shop_per_page' ) ) {
	add_filter( 'loop_shop_per_page', 'vntd_loop_shop_per_page', 20 );

	function vntd_loop_shop_per_page() {

		$product_count = 8;

		if ( isset( $_GET['product_count'] ) ) {
			$product_count = $_GET['product_count'];
		}

		return $product_count;

	}
}

//
// Nav Cart
//

if ( ! function_exists( 'woo_nav_cart' ) ) {
	function woo_nav_cart() {
		global $woocommerce;

		$cart_count = $woocommerce->cart->get_cart_contents_count();
		if($cart_count == 0) $inactive = ' nav-cart-inactive'; ?>

		<div id="woo-nav-cart" class="nav-cart<?php echo esc_attr($inactive); ?>">
			<div class="nav-cart-content">
				<i class="fa fa-shopping-cart"></i>
				<span class="woo-cart-count"><?php echo esc_textarea($cart_count); ?></span>
			</div>
			<div class="nav-cart-products">
				<div class="widget_shopping_cart"><div class="widget_shopping_cart_content"></div></div>
			</div>
		</div>

	<?php
	}
}
//
// Product thumbnail
//

if ( ! function_exists( 'woo_nav_cart' ) ) {
	add_action('woocommerce_before_shop_loop_item_title', 'purity_product_custom_thumbnail', 10);

	function purity_product_custom_thumbnail() {

		global $product;

		$thumb_size = 'shop_catalog';
		$product_id = get_the_ID();

		$output = '<div class="product-thumbnail">';
		// Check if there is a gallery

		$attachment_ids = $product->get_gallery_attachment_ids();
		if ($attachment_ids) {
			$hover_image_id = array_shift($attachment_ids);
			$output .= wp_get_attachment_image($hover_image_id, $thumb_size, '', 'class=product-hover-image');
		}

		// Continue

		$output .= get_the_post_thumbnail($product_id, $thumb_size);
		$output .= '<div class="product-loading"><i class="fa fa-refresh icon-refresh"></i></div>';
		$output .= '</div>';

		echo '' . $output;

	}
}

if ( ! function_exists( 'purity_wc_thumb_cols' ) ) {
	add_filter ( 'woocommerce_product_thumbnails_columns', 'purity_wc_thumb_cols' );
	function purity_wc_thumb_cols() {
		return 4; // .last class applied to every 4th thumbnail
	}
}
